//==================================================================================================
//
// This program allows computing the thermal SZ and kinematic effect using the improved basis of 
// Chluba, Nagai, Sazonov & Nelson, 2012. Up to 20th order temperature corrections are allowed. 
// Kinematic corrections can be included up to second order in the clusters peculiar velocity. 
// The SZ signals are computed in the cluster frame. For x <30, 5keV < Te < 25keV and beta <0.01  
// the obtained SZ signal should be accurate at the level of 0.001% when 20 temperature terms are 
// included. For Te < 5keV the asymptotic expansions should be used.
//
//==================================================================================================
//
// Author: Jens Chluba  (CITA, University of Toronto)
//
// first implementation: April 2012
// last modification   : June 2012
//
//==================================================================================================

#ifndef SZ_CNSN_BASIS_H
#define SZ_CNSN_BASIS_H

using namespace std;

//==================================================================================================
//
// compute Dn using asymptotic expansion
//
// mode == "monopole"      --> only scattering of monopole without second order kinematic corr
// mode == "dipole"        --> only scattering of dipole     (first order kinematic correction)
// mode == "quadrupole"    --> only scattering of quadrupole (second order kinematic correction)
// mode == "monopole_corr" --> only scattering of second order kinematic correction to monopole
// mode == "all"           --> all terms added
// mode == "kin"           --> only kinematic terms
//
//==================================================================================================
double compute_SZ_distortion_CNSN_basis(double x, 
                                        double The, double betac, double muc, 
                                        int Te_order, int betac_order,
                                        string mode);

#endif

//==================================================================================================
//==================================================================================================
